#!/usr/bin/env python
# -*- coding:utf-8 -*-
from setuptools import setup

setup(
    name='pypi_package_test',
    version='0.1.1',
    url='https://github.com/Miss-chan/pypi_package_test',
    install_requires=['scrapy>=1.5.1'],
)
